import type from '../../_data/typography/typography.json';

export default {
	base: type[ 'font-size-14' ],
	xxs: type[ 'font-size-11' ],
	xs: type[ 'font-size-12' ],
	sm: type[ 'font-size-13' ],
	md: type[ 'font-size-14' ],
	lg: type[ 'font-size-15' ],
	xl: type[ 'font-size-base' ],
};
